@@ -16,7 +16,7 @@ class EmptyArgumentException(InvalidArgument):
 
 class AcceptedException(Exception):
     """
-    Exception risen when an operation cannot be fully completed,
+    Exception raised when an operation cannot be fully completed,
     but doesn't imply failure.
     """
 
@@ -28,6 +28,10 @@ class AcceptedException(Exception):
         super().__init__(message)
 
 
+class ConflictException(Exception):
+    """Common exception for conflict scenarios."""
+
+
 class ObjectNotFound(Exception):
     """
     Exception risen when an object that is necessary to complete
